/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.Column;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.MappedSuperclass;

@MappedSuperclass
public class MetricMeasure {

  @Column(name = "value", updatable = false, nullable = true, precision = 30, scale = 20)
  protected Double value;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "metric_id")
  @Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
  protected Metric metric;
  
  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "snapshot_id")
  protected Snapshot snapshot;
  
  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "rule_id")
  @Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
  private Rule rule;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "rules_category_id")
  @Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
  private RulesCategory rulesCategory;
  
  public Double getValue() {
    return value;
  }

  public void setValue(Double value) {
    this.value = value;
  }

  public Metric getMetric() {
    return metric;
  }

  public void setMetric(Metric metric) {
    this.metric = metric;
  }
  
  public Snapshot getSnapshot() {
    return snapshot;
  }

  public void setSnapshot( Snapshot snapshot) {
    this.snapshot = snapshot;
  }
  
  public Rule getRule() {
    return rule;
  }

  public void setRule(Rule rule) {
    this.rule = rule;
  }

  public RulesCategory getRulesCategory() {
    return rulesCategory;
  }

  public Integer getRulesCategoryId() {
    if (getRulesCategory()!=null) {
      return getRulesCategory().getId();
    }
    return null;
  }

  public Integer getRuleId() {
    if (getRule()!=null) {
      return getRule().getId();
    }
    return null;
  }

  public void setRulesCategory(RulesCategory rulesCategory) {
    this.rulesCategory = rulesCategory;
  }
  
}
