/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.commons;

import ch.hortis.sonar.model.Metric;
import ch.hortis.sonar.model.MetricType;

import java.util.Collection;
import java.util.List;

public interface MetricsRepository {
  static final String DOMAIN_TESTS = "Tests";

  Metric getMetric(Metric metric);

  Collection<Metric> getMetrics();

  List<Metric> getTendenciableMetrics();

  // General metrics

  static final Metric NCSS = new Metric("ncss", "Non Commenting Source Statements", MetricType.INT, -1, null, "NCSS", "Non Commenting Source Statements", false, true);

  static final Metric PACKAGES_COUNT = new Metric("packages_count", "Packages", MetricType.INT, -1, null, "Packages", "Nb of Packages", false, true);

  static final Metric COMPLEXITY_TOTAL = new Metric("ccn", "Cyclomatic complexity", MetricType.INT, -1, "Complexity", "Total complexity", "Total complexity", false, true);

  static final Metric CLASSES_COUNT = new Metric("classes_count", "Classes", MetricType.INT, -1, null, "Classes", "Nb of classes", false, true);

  static final Metric FUNCTIONS_COUNT = new Metric("functions_count", "Methods", MetricType.INT, -1, null, "Methods", "Nb of methods", false, true);

  static final Metric COMMENT_LINES = new Metric("comment_lines", "Comment lines", MetricType.INT, 1, null, "Comment lines", "Comment lines", false, false);

  static final Metric COMMENT_RATIO = new Metric("comment_ratio", "Comments", MetricType.PERCENTAGE, 1, null, "Comments", "Comments", true, false);

  static final Metric SUREFIRE_TESTS = new Metric("test_count", "Test count", MetricType.INT, -1, null, "Test count", "Test count", false, false);

  static final Metric SUREFIRE_TIME = new Metric("test_execution_time", "Test execution time", MetricType.INT, -1, null, "Test execution time", "Test execution time", false, false);

  static final Metric SUREFIRE_ERRORS = new Metric("test_errors_count", "Test errors count", MetricType.INT, -1, null, "Test errors count", "Test errors count", false, false);

  static final Metric SUREFIRE_SKIPPED = new Metric("test_skipped_count", "Test skipped count", MetricType.INT, -1, null, "Test skipped count", "Test skipped count", false, false);

  static final Metric SUREFIRE_FAILURES = new Metric("test_failures_count", "Test failures count", MetricType.INT, -1, null, "Test failures count", "Test failures count", false, false);

  static final Metric CODE_COVERAGE = new Metric("code_coverage", "Code coverage", MetricType.PERCENTAGE, 1, DOMAIN_TESTS, "Code coverage", "Code coverage", true, true);

  static final Metric DUPLICATED_LINES = new Metric("duplicated_lines", "Duplicated lines", MetricType.INT, -1, null, "Duplicated lines", "Duplicated lines", false, false);

  static final Metric DUPLICATED_LINES_RATIO = new Metric("duplicated_lines_ratio", "Duplicated lines ratio", MetricType.PERCENTAGE, -1, null, "Duplicated lines ratio", "Duplicated lines ratio", false, false);

  static final Metric SUREFIRE_SUCCESS_PERCENTAGE = new Metric("test_success_percentage", "Test success percentage", MetricType.INT, -1, null, "Test success percentage", "Test success percentage", false, false);

  static final Metric SUREFIRE_ERRORS_PERCENTAGE = new Metric("test_errors_percentage", "Test errors percentage", MetricType.INT, -1, null, "Test errors percentage", "Test errors percentage", false, false);

  static final Metric SUREFIRE_FAILURE_PERCENTAGE = new Metric("test_failure_percentage", "Test failure percentage", MetricType.INT, -1, null, "Test failure percentage", "Test failure percentage", false, false);

  static final Metric CYCLOMATIC_COMPLEXITY_WEIGHT_CLASS = new Metric("ccn_class", "ccn_class", MetricType.INT, -1, null, "ccn_class", "ccn_class", false, false);

  static final Metric CYCLOMATIC_COMPLEXITY_WEIGHT_FUNCTION = new Metric("ccn_function", "ccn_function", MetricType.INT, -1, null, "ccn_function", "ccn_function", false, false);

  static final Metric ERROR_RULES_COUNT = new Metric("rules_violations", "rules_violations", MetricType.INT, -1, null, "rules_violations", "rules_violations", false, false);

  static final Metric ERROR_RULES_INDEX = new Metric("rules_compliance", "rules_compliance", MetricType.INT, -1, null, "rules_compliance", "rules_compliance", false, false);

  static final Metric WARNING_RULES_COUNT = new Metric("optional_rules_violations", "optional_rules_violations", MetricType.INT, -1, null, "optional_rules_violations", "optional_rules_violations", false, false);

  static final Metric WARNING_RULES_INDEX = new Metric("optional_rules_compliance", "optional_rules_compliance", MetricType.INT, -1, null, "optional_rules_compliance", "optional_rules_compliance", false, false);

  static final Metric FAILURE_RULES_INDEX = new Metric("strict_rules_compliance", "strict_rules_compliance", MetricType.INT, -1, null, "strict_rules_compliance", "strict_rules_compliance", false, false);

  static final Metric COMPLEXITY_CLASSES_COUNT_DISTRIBUTION = new Metric("ccn_classes_count_distribution", "ccn_classes_count_distribution", MetricType.INT, -1, null, "ccn_classes_count_distribution", "ccn_classes_count_distribution", false, false);

  static final Metric COMPLEXITY_CLASSES_PERCENT_DISTRIBUTION = new Metric("ccn_classes_percent_distribution", "ccn_classes_percent_distribution", MetricType.INT, -1, null, "ccn_classes_percent_distribution", "ccn_classes_percent_distribution", false, false);

}
